@@ -34,6 +34,8 @@ import magic
 
 from tempfile import mkstemp
 
+from inspire_utils.dedupers import dedupe_list
+
 from .engine import (
     get_kbs,
     get_plaintext_document_body,
@@ -43,8 +45,9 @@ from .engine import (
 from .errors import FullTextNotAvailableError
 from .find import (find_numeration_in_body,
                    get_reference_section_beginning)
-from .pdf import extract_texkeys_from_pdf
+from .pdf import extract_texkeys_and_urls_from_pdf
 from .text import extract_references_from_fulltext, rebuild_reference_lines
+from .record import update_reference_with_urls
 
 
 def extract_references_from_url(url, headers=None, chunk_size=1024, **kwargs):
@@ -140,10 +143,16 @@ def extract_references_from_file(path,
     )
 
     if magic.from_file(path, mime=True) == "application/pdf":
-        texkeys = extract_texkeys_from_pdf(path)
-        if len(texkeys) == len(parsed_refs):
-            parsed_refs = [dict(ref, texkey=[key]) for ref, key in zip(parsed_refs, texkeys)]
+        extracted_texkeys_urls = extract_texkeys_and_urls_from_pdf(path)
+        if len(extracted_texkeys_urls) == len(parsed_refs):
+            parsed_refs_updated = []
+            for ref, ref_texkey_urls in zip(parsed_refs, extracted_texkeys_urls):
+                update_reference_with_urls(ref, ref_texkey_urls.get('urls', []))
+                if ref.get('url'):
+                    ref['url'] = dedupe_list(ref['url'])
+                parsed_refs_updated.append(dict(ref, texkey=[ref_texkey_urls['texkey']]))
 
+            return parsed_refs_updated
     return parsed_refs
 
 
